@@ -90,7 +90,7 @@ class UWC_Data {
 		   uwc_format_escape_sql($lang),
 		   uwc_format_escape_sql($title),
 		   uwc_format_escape_sql($author),
-		   uwc_format_escape_sql($text),
+		   uwc_format_escape_sql(uwc_format_fix_content_text($text)),
 		   (int) uwc_format_escape_sql($status),
 		   (int) uwc_format_escape_sql($next_order));
     $this->query($query);    
@@ -101,7 +101,7 @@ class UWC_Data {
     $query=sprintf($this->sql->query["update_content"],
 		   uwc_format_escape_sql($title),
 		   uwc_format_escape_sql($author),
-		   uwc_format_escape_sql($text),
+		   uwc_format_escape_sql(uwc_format_fix_content_text($text)),
 		   (int) uwc_format_escape_sql($status),
 		   (int) uwc_format_escape_sql($order),
 		   uwc_format_escape_sql($path),
