@@ -459,15 +459,15 @@ class UWC_Page {
   }
 
   function get_absolute_url() {
-    return $this->conf->siteurl.$this->make_url($this->get_path());
+    return $this->conf->siteurl.$this->make_url($this->get_path(),array("login"=>"","password"=>""));
   }
 
   function get_absolute_url_no_esc() {
-    return $this->conf->siteurl.$this->make_url_no_esc($this->get_path());
+    return $this->conf->siteurl.$this->make_url_no_esc($this->get_path(),array("login"=>"","password"=>""));
   }
 
   function get_absolute_url_clean() {
-    return $this->conf->siteurl.$this->make_url($this->get_path(),array("session"=>""));
+    return $this->conf->siteurl.$this->make_url($this->get_path(),array("login"=>"","password"=>"","session"=>""));
   }
 
   function need_absolute_url() {
@@ -959,11 +959,20 @@ class UWC_Page {
       break;
     }
 
+    if ($this->context->request->has_key("password")) {
+      /*
+       * If there's a password in the request, we replace
+       * it on the fly with a crypted session.
+       */
+      header("Location: ".$this->get_absolute_url_no_esc());
+      return;
+    }
+
     switch ($this->context->action) {
     case "new":
       /* Path is automatically changed within the context object */
       header("Location: ".$this->get_absolute_url_no_esc());
-      break;
+      return;
     case "403":
       $this->set_http_code(403);
       break;
@@ -1057,9 +1066,6 @@ class UWC_Page {
       uwc_gallery_xul_header();
       include $this->get_prefix()."/_uwikicms/template/php/".$this->context->action.".php";
       break;
-    case "new":
-      // header "Location" so no content...
-      break;
     default:
       /*
        * General case, we use the template system.
